@@ -105,6 +105,11 @@ class Remove_duplicate_time(object):
                     new_stroke.append(point)
                     t.append(point['time'])
             new_pointlist.append(new_stroke)
+        # Make sure there are no duplicates
+        times = [point['time'] for point in pointlist for stroke in pointlist]
+        assert len(times) == len(set(times)), \
+            ("The list of all times in Remove_duplicate_time has %i values, "
+             "but the set has %i values.") % (len(times), len(set(times)))
         handwritten_data.set_pointlist(new_pointlist)
 
 
